package com.diagbot.facade;

import com.diagbot.client.AIServiceClient;
import com.diagbot.client.bean.GdbResponse;
import com.diagbot.client.bean.Response;
import com.diagbot.client.bean.ResponseData;
import com.diagbot.dto.LisResult;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.vo.SearchVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;
import java.util.Map;

/**
 * <p>
 *  数据处理业务层
 * </p>
 *
 * @author Mark Huang
 * @since 2019-03-04
 */
@Component
public class ClinicalFacade {

    @Autowired
    private AIServiceClient aiServiceClient;

    /**
     * 处理临床数据
     *
     * @param searchVo
     * @return ResponseData
     */
    public ResponseData processClinicalData(@RequestBody SearchVo searchVo) {
        SearchVo sData = searchVo;

        sData.setLisArr(processLis(sData.getLisArr()));
        Response<ResponseData> res = aiServiceClient.bayesPageData(sData);

        return res.getData();
    }

    private List<LisResult> processLis(List<LisResult> lisArr) {

        String Otherval = "";

        for (int i = 0; i < lisArr.size(); i++) {
            LisResult lisres = lisArr.get(i);

            Otherval = (lisres.getOtherValue().trim().length() > 0) ? lisres.getOtherValue().trim() + "\n" : "";

            if (lisres.getMaxValue() != null && lisres.getValue() > lisres.getMaxValue()) {
                lisres.setOtherValue(Otherval + "超出标准");
            } else if (lisres.getMinValue() != null && lisres.getValue() < lisres.getMinValue()) {
                lisres.setOtherValue(Otherval + "低于标准");
            }
        }

        return lisArr;
    }

    /**
     * 获取量表内容
     *
     * @param searchVo
     * @return
     */
    public Map<String, Object> scale(SearchVo searchVo) {
        Map<String, Object> response = aiServiceClient.scale(searchVo);
        if (null == response) {
            throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "量表没有返回结果");
        }
        return response;
    }

    /**
     * 高危诊断
     *
     * @param searchVo
     * @return
     */
    public GdbResponse highRiskPageData(SearchVo searchVo) {
        Response<GdbResponse> response = aiServiceClient.highRiskPageData(searchVo);
        if (response == null || response.getData() == null) {
            throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "高危没有返回结果");
        }
        return response.getData();
    }
}
