package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.LisMappingFacade;
import com.diagbot.vo.IdListVO;
import com.diagbot.vo.IdVO;
import com.diagbot.vo.LisMappingPageVO;
import com.diagbot.vo.LisMappingVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 化验项目公表映射 前端控制器
 * </p>
 *
 * @author zhaops
 * @since 2019-03-26
 */
@RestController
@RequestMapping("/lisMapping")
@SuppressWarnings("unchecked")
@Api(value = "化验公表项映射维护相关API", tags = { "2期-化验公表项映射维护相关API" })
public class LisMappingController {
    @Autowired
    private LisMappingFacade lisMappingFacade;

    /**
     * 分页查询提示信息，带条件查询
     *
     * @param lisMappingPageVO
     * @return
     */
    @ApiOperation(value = "2期-分页查询提示信息，带条件[by:zhaops]",
            notes = "current:页码，必填<br>" +
                    "size:每页显示条数，必填<br>" +
                    "mealName:大项名称<br>" +
                    "itemName:小项名称<br>" +
                    "uniqueName:公表名称<br>")
    @PostMapping("/getLisMappingPage")
    @SysLogger("getLisMappingPage")
    public RespDTO getLisMappingPage(@RequestBody LisMappingPageVO lisMappingPageVO) {
        return RespDTO.onSuc(lisMappingFacade.getLisMappingPage(lisMappingPageVO));
    }

    @ApiOperation(value = "2期-化验公表项映射新增[by:zhaops]",
            notes = "mealName:大项名称，必填<br>" +
                    "itemName:小项名称<br>" +
                    "uniqueName:公表名称，必填<br>" +
                    "备注:错误码00020009 提示是否修改，是，调用修改接口<br>")
    @PostMapping("/addLisMapping")
    @SysLogger("addLisMapping")
    @Transactional
    public RespDTO<Boolean> addLisMapping(@RequestBody @Valid LisMappingVO lisMappingVO) {
        return RespDTO.onSuc(lisMappingFacade.addLisMapping(lisMappingVO));
    }

    @ApiOperation(value = "2期-化验公表项映射修改[by:zhaops]",
            notes = "mealName:大项名称，必填<br>" +
                    "itemName:小项名称<br>" +
                    "uniqueName:公表名称，必填<br>")
    @PostMapping("/modifyLisMapping")
    @SysLogger("modifyLisMapping")
    @Transactional
    public RespDTO<Boolean> modifyLisMapping(@RequestBody @Valid LisMappingVO lisMappingVO) {
        return RespDTO.onSuc(lisMappingFacade.modifyLisMapping(lisMappingVO));
    }

    @ApiOperation(value = "2期-删除单条化验公表项映射[by:zhaops]",
            notes = "id:id，必填<br>")
    @PostMapping("/delLisMappingById")
    @SysLogger("delLisMappingById")
    @Transactional
    public RespDTO<Boolean> delLisMappingById(@RequestBody @Valid IdVO idVO) {
        return RespDTO.onSuc(lisMappingFacade.delLisMappingById(idVO));
    }

    @ApiOperation(value = "2期-批量删除化验公表项映射[by:zhaops]",
            notes = "ids:ids，必填<br>")
    @PostMapping("/delLisMappingByIds")
    @SysLogger("delLisMappingByIds")
    @Transactional
    public RespDTO<Boolean> delLisMappingByIds(@RequestBody IdListVO idListVO) {
        return RespDTO.onSuc(lisMappingFacade.delLisMappingByIds(idListVO));
    }
}